Summary method for DNFOptim objects.
# S3 method for DNFOptim
summary(object, confidence, ...)# S3 method for summary.DNFOptim
print(x, digits = max(3, getOption("digits") - 3), ...)
Returns a list with the model used and its estimated parameters.
The model that was estimated with the DNFOptim object.
Table with the maximum likelihood parameters estimates. If hessian = TRUE was set in the DNFOptim function, standard errors and 95% confidence intervals are given. Then, the table has the following columns:
(1) Estimate: the parameter estimate,
(2) Std Error: the standard error of the estimate,
(3) Lower Bound: the lower bound of the confidence interval, and
(4) Upper Bound:The upper bound of the confidence interval.
Log-likelihood value at the parameter maximum likelihood estimates and the model's degrees of freedom
an object of class DNFOptim that you want to summary the parameter estimates.
an object of class summary.DNFOptim.
Confidence level for computing confidence intervals. Should be between 0 and 1. Default is 0.95.
The number of digits to be printed in the print method for summary.DNFOptim objects.
further arguments passed to or from other methods.
Returns the summary of the output of a DNFOptim object.
## For examples see example(DNFOptim)
Run the code above in your browser using DataLab